    #include <stdio.h>
#include <assert.h>
#include <climits>
#include <algorithm>
#include <unordered_map>
#include <string>

using namespace std;

#define MAXN 200

int t[MAXN+1];

/*
    Recursive solution (70 points):
        economize N users, up to time t[i+1], with K increments to be spent up to time t[i]
int economize(int K, int i, int N) {
    // base case: only one possible increment left
    if(K == 1) return N * (t[i+1] - t[0]);
    
    // two possibilities
    int increment_kept = K <= i ? economize(K, i-1, N) : INT_MAX;
    int increment_spent = economize(K-1, i-1, i);
    return N * (t[i+1] - t[i]) + min(increment_kept, increment_spent);
}
*/

/*
    as above, but with memoization (100 points)
*/

// perfect hash (as MAXN is very small)
inline int get_key(int K, int i, int N) {
    return K + i * 201 + N * 201 * 201;
}

unordered_map<int, int> res;    // already computed results

int economize(int K, int i, int N) {
    int key = get_key(K, i, N);
    auto it = res.insert(make_pair(key, -1)).first;
    if(it->second != -1) goto end;
    
    // base case: only one possible increment left
    if(K == 1) { it->second = N * (t[i+1] - t[0]); goto end; }
    
    {
        // two possibilities
        int increment_kept = K <= i ? economize(K, i-1, N) : INT_MAX;
        int increment_spent = economize(K-1, i-1, i);
        it->second = N * (t[i+1] - t[i]) + min(increment_kept, increment_spent);
    }
    
    end: return it->second;
}

int main() {
    FILE *fr, *fw;
    int T, K, N, i;

    fr = fopen("input.txt", "r");
    fw = fopen("output.txt", "w");
    assert(3 == fscanf(fr, "%d %d %d", &T, &K, &N));
    for(i=0; i<N; i++)
        assert(1 == fscanf(fr, "%d", &t[i]));
    
    t[N] = T;
    fprintf(fw, "%d\n", economize(K, N-1, N));
    fclose(fr);
    fclose(fw);
    return 0;
}
