#include <stdio.h>
#include <assert.h>

#define MAXN 1000000

int V[MAXN];

/*
    Recursive solution: it repeats several calls (35 points)

int receive(int N) {
    if(N <= 0) return 1;    // only the empty set
    if(V[N-1] == 0) return (2 * receive(N-1)) % 1000000007;     // we are free to take the radio
    return (receive(N-1) + receive(N-V[N-1]-1)) % 1000000007;   // if we take the radio, we cannot take some radio on the left
}

*/

/*
    Recursion with memoization (100 points)
    
int res[MAXN+1];
int receive(int N) {
    if(N <= 0) return 1;    // only the empty set
    if(res[N] == -1) {
        if(V[N-1] == 0) res[N] = (2 * receive(N-1)) % 1000000007;     // we are free to take the radio
        res[N] = (receive(N-1) + receive(N-V[N-1]-1)) % 1000000007;   // if we take the radio, we cannot take some radio on the left
    }
    return res[N];
}

*/

/*
    Iterative solution (100 points)
*/
int receive(int N) {
    int res[N+1];
    res[0] = 1;
    for(int i = 1; i <= N; i++) {
        if(V[i-1] == 0) res[i] = (2 * res[i-1]) % 1000000007;     // we are free to take the radio
        else res[i] = (res[i-1] + (V[i-1] > i ? 1 : res[i-V[i-1]-1])) % 1000000007;   // if we take the radio, we cannot take some radio on the left
    }
    return res[N];
}

int main() {
    FILE *fr, *fw;
    int N, i;

    fr = fopen("input.txt", "r");
    fw = fopen("output.txt", "w");
    assert(1 == fscanf(fr, "%d", &N));
    for(i=0; i<N; i++) {
        //res[i+1] = -1;
        assert(1 == fscanf(fr, "%d", &V[i]));
    }

    fprintf(fw, "%d\n", receive(N));
    fclose(fr);
    fclose(fw);
    return 0;
}
